<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:saxon="http://saxon.sf.net/" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:xsd="http://www.w3.org/2001/XMLSchema"
	xmlns:schold="http://www.ascc.net/xml/schematron" xmlns:iso="http://purl.oclc.org/dsdl/schematron"
	xmlns:crt="urn:nzl:govt:educating:specification:csl:schema:xsd:SmsStudentMembership-3"
	xmlns:cac="urn:nzl:govt:educating:specification:esl:schema:xsd:CommonAggregateComponents-7"
	xmlns:caccs="urn:nzl:govt:educating:specification:csl:schema:xsd:CommonAggregateComponents-7"
	xmlns:cbc="urn:nzl:govt:educating:specification:esl:schema:xsd:CommonBasicComponents-7"
	xmlns:cbccs="urn:nzl:govt:educating:specification:csl:schema:xsd:CommonBasicComponents-6"
	version="2.0"><!--Importing stylesheet additions -->
	<xsl:output xmlns:sch="http://www.ascc.net/xml/schematron"
		method="text" />
	<!--Implementers: please note that overriding process-prolog or process-root 
		is the preferred method for meta-stylesheets to use where possible. -->
	<xsl:param name="archiveDirParameter" />
	<xsl:param name="archiveNameParameter" />
	<xsl:param name="fileNameParameter" />
	<xsl:param name="fileDirParameter" />
	<xsl:variable name="document-uri">
		<xsl:value-of select="document-uri(/)" />
	</xsl:variable>

	<!--PHASES -->


	<!--PROLOG -->


	<!--XSD TYPES FOR XSLT2 -->


	<!--KEYS AND FUNCTIONS -->
	<xsl:key name="Key-Unique-Person-Class" match="crt:Person/crt:ClassParticipation/crt:Class"
		use="concat(../../crt:LearnerRegistration/cbc:NationalStudentNumberID, '-', cbc:SystemIDNumeric)" />

	<!--DEFAULT RULES -->


	<!--MODE: SCHEMATRON-SELECT-FULL-PATH -->
	<!--This mode can be used to generate an ugly though full XPath for locators -->
	<xsl:template match="*" mode="schematron-select-full-path">
		<xsl:apply-templates select="."
			mode="schematron-get-full-path" />
	</xsl:template>

	<!--MODE: SCHEMATRON-FULL-PATH -->
	<!--This mode can be used to generate an ugly though full XPath for locators -->
	<xsl:template match="*" mode="schematron-get-full-path">
		<xsl:apply-templates select="parent::*"
			mode="schematron-get-full-path" />
		<xsl:text>/</xsl:text>
		<xsl:choose>
			<xsl:when test="namespace-uri()=''">
				<xsl:value-of select="name()" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>*:</xsl:text>
				<xsl:value-of select="local-name()" />
				<xsl:text>[namespace-uri()='</xsl:text>
				<xsl:value-of select="namespace-uri()" />
				<xsl:text>']</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:variable name="preceding"
			select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])" />
		<xsl:text>[</xsl:text>
		<xsl:value-of select="1+ $preceding" />
		<xsl:text>]</xsl:text>
	</xsl:template>
	<xsl:template match="@*" mode="schematron-get-full-path">
		<xsl:apply-templates select="parent::*"
			mode="schematron-get-full-path" />
		<xsl:text>/</xsl:text>
		<xsl:choose>
			<xsl:when test="namespace-uri()=''">
				@
				<xsl:value-of select="name()" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>@*[local-name()='</xsl:text>
				<xsl:value-of select="local-name()" />
				<xsl:text>' and namespace-uri()='</xsl:text>
				<xsl:value-of select="namespace-uri()" />
				<xsl:text>']</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!--MODE: SCHEMATRON-FULL-PATH-2 -->
	<!--This mode can be used to generate prefixed XPath for humans -->
	<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
		<xsl:for-each select="ancestor-or-self::*">
			<xsl:text>/</xsl:text>
			<xsl:value-of select="name(.)" />
			<xsl:if test="preceding-sibling::*[name(.)=name(current())]">
				<xsl:text>[</xsl:text>
				<xsl:value-of
					select="count(preceding-sibling::*[name(.)=name(current())])+1" />
				<xsl:text>]</xsl:text>
			</xsl:if>
		</xsl:for-each>
		<xsl:if test="not(self::*)">
			<xsl:text />
			/@
			<xsl:value-of select="name(.)" />
		</xsl:if>
	</xsl:template>
	<!--MODE: SCHEMATRON-FULL-PATH-3 -->
	<!--This mode can be used to generate prefixed XPath for humans (Top-level 
		element has index) -->
	<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
		<xsl:for-each select="ancestor-or-self::*">
			<xsl:text>/</xsl:text>
			<xsl:value-of select="name(.)" />
			<xsl:if test="parent::*">
				<xsl:text>[</xsl:text>
				<xsl:value-of
					select="count(preceding-sibling::*[name(.)=name(current())])+1" />
				<xsl:text>]</xsl:text>
			</xsl:if>
		</xsl:for-each>
		<xsl:if test="not(self::*)">
			<xsl:text />
			/@
			<xsl:value-of select="name(.)" />
		</xsl:if>
	</xsl:template>

	<!--MODE: GENERATE-ID-FROM-PATH -->
	<xsl:template match="/" mode="generate-id-from-path" />
	<xsl:template match="text()" mode="generate-id-from-path">
		<xsl:apply-templates select="parent::*"
			mode="generate-id-from-path" />
		<xsl:value-of
			select="concat('.text-', 1+count(preceding-sibling::text()), '-')" />
	</xsl:template>
	<xsl:template match="comment()" mode="generate-id-from-path">
		<xsl:apply-templates select="parent::*"
			mode="generate-id-from-path" />
		<xsl:value-of
			select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')" />
	</xsl:template>
	<xsl:template match="processing-instruction()" mode="generate-id-from-path">
		<xsl:apply-templates select="parent::*"
			mode="generate-id-from-path" />
		<xsl:value-of
			select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')" />
	</xsl:template>
	<xsl:template match="@*" mode="generate-id-from-path">
		<xsl:apply-templates select="parent::*"
			mode="generate-id-from-path" />
		<xsl:value-of select="concat('.@', name())" />
	</xsl:template>
	<xsl:template match="*" mode="generate-id-from-path"
		priority="-0.5">
		<xsl:apply-templates select="parent::*"
			mode="generate-id-from-path" />
		<xsl:text>.</xsl:text>
		<xsl:value-of
			select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')" />
	</xsl:template>

	<!--MODE: GENERATE-ID-2 -->
	<xsl:template match="/" mode="generate-id-2">
		U
	</xsl:template>
	<xsl:template match="*" mode="generate-id-2" priority="2">
		<xsl:text>U</xsl:text>
		<xsl:number level="multiple" count="*" />
	</xsl:template>
	<xsl:template match="node()" mode="generate-id-2">
		<xsl:text>U.</xsl:text>
		<xsl:number level="multiple" count="*" />
		<xsl:text>n</xsl:text>
		<xsl:number count="node()" />
	</xsl:template>
	<xsl:template match="@*" mode="generate-id-2">
		<xsl:text>U.</xsl:text>
		<xsl:number level="multiple" count="*" />
		<xsl:text>_</xsl:text>
		<xsl:value-of select="string-length(local-name(.))" />
		<xsl:text>_</xsl:text>
		<xsl:value-of select="translate(name(),':','.')" />
	</xsl:template>
	<!--Strip characters -->
	<xsl:template match="text()" priority="-1" />

	<!--SCHEMA SETUP -->
	<xsl:template match="/"><!--Root node processing collects all assertions -->
		<xsl:variable xmlns:sch="http://www.ascc.net/xml/schematron"
			name="result">
			<xsl:apply-templates select="/" mode="M8" />
			<xsl:apply-templates select="/" mode="M9" />
			<xsl:apply-templates select="/" mode="M11" />
			<xsl:apply-templates select="/" mode="M12" />
			<xsl:apply-templates select="/" mode="M13" />
			<xsl:apply-templates select="/" mode="M14" />
			<xsl:apply-templates select="/" mode="M15" />
			<xsl:apply-templates select="/" mode="M16" />
			<xsl:apply-templates select="/" mode="M17" />
		</xsl:variable>
		<xsl:if xmlns:sch="http://www.ascc.net/xml/schematron" test="normalize-space(string($result))">
			<xsl:message terminate="yes">
				<xsl:value-of select="string($result)"
					disable-output-escaping="yes" />
			</xsl:message>
		</xsl:if>
	</xsl:template>

	<!--SCHEMATRON PATTERNS -->


	<!--PATTERN CSL-BusinessConstraints-Generic-4 -->


	<!--RULE -->
	<xsl:template match="*[not(*)][. = '']" priority="1004"
		mode="M8">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when test="false()" />
			<xsl:otherwise>
				ErrorMessage: Error! Content of element
				<xsl:text />
				<xsl:value-of select="name(parent::*)" />
				<xsl:text />
				//
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				must not be empty. Please contact your software supplier's helpdesk
				with this error message /ErrorMessage: TechnicalErrorMessage:
				Content of element
				<xsl:text />
				<xsl:value-of select="name(parent::*)" />
				<xsl:text />
				//
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				must not be empty. Please contact your software supplier's helpdesk
				with this error message /TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M8" />
	</xsl:template>

	<!--RULE -->
	<xsl:template match="*[not(*)][normalize-space(.) = '']"
		priority="1003" mode="M8">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when test="false()" />
			<xsl:otherwise>
				ErrorMessage: Error! Content of element
				<xsl:text />
				<xsl:value-of select="name(parent::*)" />
				<xsl:text />
				//
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				must not contain whitespace only. Please contact your software
				supplier's helpdesk with this error message /ErrorMessage:
				TechnicalErrorMessage: Content of element
				<xsl:text />
				<xsl:value-of select="name(parent::*)" />
				<xsl:text />
				//
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				must not contain whitespace only. Please contact your software
				supplier's helpdesk with this error message /TechnicalErrorMessage:
				XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M8" />
	</xsl:template>

	<!--RULE -->
	<xsl:template match="suppresses-xslt-warning-messages|@*[. = '']"
		priority="1002" mode="M8">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when test="false()" />
			<xsl:otherwise>
				ErrorMessage: Error! Content of attribute
				<xsl:text />
				<xsl:value-of select="name(parent::*)" />
				<xsl:text />
				//
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				must not be empty. Please contact your software supplier's helpdesk
				with this error message /ErrorMessage: TechnicalErrorMessage:
				Content of attribute
				<xsl:text />
				<xsl:value-of select="name(parent::*)" />
				<xsl:text />
				//
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				must not be empty. Please contact your software supplier's helpdesk
				with this error message /TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M8" />
	</xsl:template>

	<!--RULE -->
	<xsl:template
		match="suppresses-xslt-warning-messages|@*[normalize-space(.) = '']"
		priority="1001" mode="M8">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when test="false()" />
			<xsl:otherwise>
				ErrorMessage: Error! Content of attribute
				<xsl:text />
				<xsl:value-of select="name(parent::*)" />
				<xsl:text />
				//
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				must not contain whitespace only. Please contact your software
				supplier's helpdesk with this error message /ErrorMessage:
				TechnicalErrorMessage: Content of attribute
				<xsl:text />
				<xsl:value-of select="name(parent::*)" />
				<xsl:text />
				//
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				must not contain whitespace only. Please contact your software
				supplier's helpdesk with this error message /TechnicalErrorMessage:
				XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M8" />
	</xsl:template>

	<!--RULE -->
	<xsl:template match="cbc:SystemIDNumeric" priority="1000"
		mode="M8">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when test=". &gt; 0" />
			<xsl:otherwise>
				ErrorMessage: Error! SystemIDNumeric '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' of
				<xsl:text />
				<xsl:value-of select="name(..)" />
				<xsl:text />
				must be a positive integer. Please contact your software supplier's
				helpdesk with this error message /ErrorMessage:
				TechnicalErrorMessage: SystemIDNumeric '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' of
				<xsl:text />
				<xsl:value-of select="name(..)" />
				<xsl:text />
				must be a positive integer. Please contact your software supplier's
				helpdesk with this error message /TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M8" />
	</xsl:template>
	<xsl:template match="text()" priority="-1" mode="M8" />
	<xsl:template match="@*|node()" priority="-2" mode="M8">
		<xsl:apply-templates select="@*|*" mode="M8" />
	</xsl:template>

	<!--PATTERN CSL-ContextAssocConstraints-SmsStudentMembership-3 -->
	<xsl:template match="text()" priority="-1" mode="M9" />
	<xsl:template match="@*|node()" priority="-2" mode="M9">
		<xsl:apply-templates select="@*|*" mode="M9" />
	</xsl:template>

	<!--PATTERN NamespaceCheckInstanceVsSchema -->


	<!--RULE -->
	<xsl:template match="/*" priority="1000" mode="M11">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when
				test="namespace-uri(.)='urn:nzl:govt:educating:specification:csl:schema:xsd:SmsStudentMembership-3'" />
			<xsl:otherwise>
				ErrorMessage: Error! The currently running Value Validation
				Stylesheet is designed for namespace
				'urn:nzl:govt:educating:specification:csl:schema:xsd:SmsStudentMembership-3'
				and is not the correct version for this instance document with
				namespace '
				<xsl:text />
				<xsl:value-of select="namespace-uri(.)" />
				<xsl:text />
				'. The validation is unreliable. Apply the correct Value Validation
				Stylesheet version and re-validate. /ErrorMessage:
				TechnicalErrorMessage: The currently running Value Validation
				Stylesheet is designed for namespace
				'urn:nzl:govt:educating:specification:csl:schema:xsd:SmsStudentMembership-3'
				and is not the correct version for this instance document with
				namespace '
				<xsl:text />
				<xsl:value-of select="namespace-uri(.)" />
				<xsl:text />
				'. The validation is unreliable. Apply the correct Value Validation
				Stylesheet version and re-validate. /TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M11" />
	</xsl:template>
	<xsl:template match="text()" priority="-1" mode="M11" />
	<xsl:template match="@*|node()" priority="-2" mode="M11">
		<xsl:apply-templates select="@*|*" mode="M11" />
	</xsl:template>

	<!--PATTERN Root-Element -->


	<!--RULE -->
	<xsl:template match="/*" priority="1000" mode="M12">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when test="self::crt:SmsStudentMembership" />
			<xsl:otherwise>
				ErrorMessage: Error! Root element name is
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				, but must be SmsStudentMembership. /ErrorMessage:
				TechnicalErrorMessage: Root element name is
				<xsl:text />
				<xsl:value-of select="name(.)" />
				<xsl:text />
				, but must be SmsStudentMembership. /TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M12" />
	</xsl:template>
	<xsl:template match="text()" priority="-1" mode="M12" />
	<xsl:template match="@*|node()" priority="-2" mode="M12">
		<xsl:apply-templates select="@*|*" mode="M12" />
	</xsl:template>

	<!--PATTERN NationalStudentNumberIDNumeric -->


	<!--RULE -->
	<xsl:template match="cbc:NationalStudentNumberID"
		priority="1000" mode="M13">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when test="number(.)=number(.)" />
			<xsl:otherwise>
				ErrorMessage: Error! The provided NSN '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is invalid. Please remove it from the student record (SMS ID '
				<xsl:text />
				<xsl:value-of select="../../crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				') and run Get/Check NSN to retrieve the correct one from ENROL.
				/ErrorMessage: TechnicalErrorMessage: NationalStudentNumberID '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is invalid for SMSStudentNumberID ID '
				<xsl:text />
				<xsl:value-of select="../../crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				'. NationalStudentNumberID must be numeric. /TechnicalErrorMessage:
				XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M13" />
	</xsl:template>
	<xsl:template match="text()" priority="-1" mode="M13" />
	<xsl:template match="@*|node()" priority="-2" mode="M13">
		<xsl:apply-templates select="@*|*" mode="M13" />
	</xsl:template>

	<!--PATTERN NationalStudentNumberIDLength -->


	<!--RULE -->
	<xsl:template match="cbc:NationalStudentNumberID"
		priority="1000" mode="M14">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when
				test="not(number(.)=number(.))    or not(string-length(.) != 10)" />
			<xsl:otherwise>
				ErrorMessage: Error! The provided NSN '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is invalid. Please remove it from the student record (SMS ID '
				<xsl:text />
				<xsl:value-of select="../../crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				') and run Get/Check NSN to retrieve the correct one from ENROL.
				/ErrorMessage: TechnicalErrorMessage: NationalStudentNumberID '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is invalid for SMSStudentNumberID ID '
				<xsl:text />
				<xsl:value-of select="../../crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				'. NationalStudentNumberID must have 10 digits.
				/TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M14" />
	</xsl:template>
	<xsl:template match="text()" priority="-1" mode="M14" />
	<xsl:template match="@*|node()" priority="-2" mode="M14">
		<xsl:apply-templates select="@*|*" mode="M14" />
	</xsl:template>

	<!--PATTERN NationalStudentNumberIDInteger -->


	<!--RULE -->
	<xsl:template match="cbc:NationalStudentNumberID"
		priority="1000" mode="M15">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when
				test="not(number(.)=number(.))    or not(string-length(.) = 10)    or not(not(. castable as xs:integer) or not(number(.) ge 0))" />
			<xsl:otherwise>
				ErrorMessage: Error! The provided NSN '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is invalid. Please remove it from the student record (SMS ID '
				<xsl:text />
				<xsl:value-of select="../../crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				') and run Get/Check NSN to retrieve the correct one from ENROL.
				/ErrorMessage: TechnicalErrorMessage: NationalStudentNumberID '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is invalid for SMSStudentNumberID ID '
				<xsl:text />
				<xsl:value-of select="../../crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				'. NationalStudentNumberID must be an unsigned integer.
				/TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M15" />
	</xsl:template>
	<xsl:template match="text()" priority="-1" mode="M15" />
	<xsl:template match="@*|node()" priority="-2" mode="M15">
		<xsl:apply-templates select="@*|*" mode="M15" />
	</xsl:template>

	<!--PATTERN NationalStudentNumberIDCheckDigit -->


	<!--RULE -->
	<xsl:template match="cbc:NationalStudentNumberID"
		priority="1000" mode="M16">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when
				test="not(number(.)=number(.))    or not(string-length(.) = 10)    or not(. castable as xs:integer and number(.) ge 0)    or not((number(substring(.,1,1))*31 + number(substring(.,2,1))*29 + number(substring(.,3,1))*23 + number(substring(.,4,1))*19 + number(substring(.,5,1))*17 + number(substring(.,6,1))*13 + number(substring(.,7,1))*7 + number(substring(.,8,1))*5 + number(substring(.,9,1))*3) mod 11 != number(substring(.,10,1)))" />
			<xsl:otherwise>
				ErrorMessage: Error! The provided NSN '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is invalid. Please remove it from the student record (SMS ID '
				<xsl:text />
				<xsl:value-of select="../../crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				') and run Get/Check NSN to retrieve the correct one from ENROL.
				/ErrorMessage: TechnicalErrorMessage: NationalStudentNumberID '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is invalid for SMSStudentNumberID ID '
				<xsl:text />
				<xsl:value-of select="../../crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				'. The check digit is invalid. /TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M16" />
	</xsl:template>
	<xsl:template match="text()" priority="-1" mode="M16" />
	<xsl:template match="@*|node()" priority="-2" mode="M16">
		<xsl:apply-templates select="@*|*" mode="M16" />
	</xsl:template>

	<!--PATTERN Person-Class-Unique-SystemIDNumeric -->


	<!--RULE -->
	<xsl:template
		match="crt:Person/crt:ClassParticipation/crt:Class/cbc:SystemIDNumeric"
		priority="1000" mode="M17">

		<!--ASSERT -->
		<xsl:choose>
			<xsl:when
				test="count(key('Key-Unique-Person-Class', concat(../../../crt:LearnerRegistration/cbc:NationalStudentNumberID, '-',.))) = 1" />
			<xsl:otherwise>
				ErrorMessage: Error! The Class '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' appears more than once in the student membership message for the
				student with the SMS ID '
				<xsl:text />
				<xsl:value-of select="ancestor::crt:Person/crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				'. /ErrorMessage: TechnicalErrorMessage: Class SystemIDNumeric '
				<xsl:text />
				<xsl:value-of select="." />
				<xsl:text />
				' is a duplicate key but must be unique within SMSStudentNumberID ID
				'
				<xsl:text />
				<xsl:value-of select="ancestor::crt:Person/crt:SMSStudentNumberID/cbc:ID" />
				<xsl:text />
				'. /TechnicalErrorMessage: XPath
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
				<xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
					select="." mode="schematron-get-full-path-3" />
				<xsl:text xmlns:sch="http://www.ascc.net/xml/schematron"
					xml:space="preserve">
</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="@*|*" mode="M17" />
	</xsl:template>
	<xsl:template match="text()" priority="-1" mode="M17" />
	<xsl:template match="@*|node()" priority="-2" mode="M17">
		<xsl:apply-templates select="@*|*" mode="M17" />
	</xsl:template>
</xsl:stylesheet>